@@ -13,7 +13,6 @@
 
 #include "soup-auth-domain-basic.h"
 #include "soup.h"
-#include "soup-marshal.h"
 
 /**
  * SECTION:soup-auth-domain-basic
@@ -38,9 +37,7 @@ typedef struct {
 	GDestroyNotify auth_dnotify;
 } SoupAuthDomainBasicPrivate;
 
-#define SOUP_AUTH_DOMAIN_BASIC_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SOUP_TYPE_AUTH_DOMAIN_BASIC, SoupAuthDomainBasicPrivate))
-
-G_DEFINE_TYPE (SoupAuthDomainBasic, soup_auth_domain_basic, SOUP_TYPE_AUTH_DOMAIN)
+G_DEFINE_TYPE_WITH_PRIVATE (SoupAuthDomainBasic, soup_auth_domain_basic, SOUP_TYPE_AUTH_DOMAIN)
 
 static void
 soup_auth_domain_basic_init (SoupAuthDomainBasic *basic)
@@ -51,7 +48,7 @@ static void
 soup_auth_domain_basic_finalize (GObject *object)
 {
 	SoupAuthDomainBasicPrivate *priv =
-		SOUP_AUTH_DOMAIN_BASIC_GET_PRIVATE (object);
+		soup_auth_domain_basic_get_instance_private (SOUP_AUTH_DOMAIN_BASIC (object));
 
 	if (priv->auth_dnotify)
 		priv->auth_dnotify (priv->auth_data);
@@ -64,7 +61,7 @@ soup_auth_domain_basic_set_property (GObject *object, guint prop_id,
 				     const GValue *value, GParamSpec *pspec)
 {
 	SoupAuthDomainBasicPrivate *priv =
-		SOUP_AUTH_DOMAIN_BASIC_GET_PRIVATE (object);
+		soup_auth_domain_basic_get_instance_private (SOUP_AUTH_DOMAIN_BASIC (object));
 
 	switch (prop_id) {
 	case PROP_AUTH_CALLBACK:
@@ -88,7 +85,7 @@ soup_auth_domain_basic_get_property (GObject *object, guint prop_id,
 				     GValue *value, GParamSpec *pspec)
 {
 	SoupAuthDomainBasicPrivate *priv =
-		SOUP_AUTH_DOMAIN_BASIC_GET_PRIVATE (object);
+		soup_auth_domain_basic_get_instance_private (SOUP_AUTH_DOMAIN_BASIC (object));
 
 	switch (prop_id) {
 	case PROP_AUTH_CALLBACK:
@@ -133,7 +130,7 @@ soup_auth_domain_basic_new (const char *optname1, ...)
 
 /**
  * SoupAuthDomainBasicAuthCallback:
- * @domain: the domain
+ * @domain: (type SoupAuthDomainBasic): the domain
  * @msg: the message being authenticated
  * @username: the username provided by the client
  * @password: the password provided by the client
@@ -159,7 +156,7 @@ soup_auth_domain_basic_new (const char *optname1, ...)
 
 /**
  * soup_auth_domain_basic_set_auth_callback:
- * @domain: the domain
+ * @domain: (type SoupAuthDomainBasic): the domain
  * @callback: the callback
  * @user_data: data to pass to @auth_callback
  * @dnotify: destroy notifier to free @user_data when @domain
@@ -182,7 +179,7 @@ soup_auth_domain_basic_set_auth_callback (SoupAuthDomain *domain,
 					  GDestroyNotify  dnotify)
 {
 	SoupAuthDomainBasicPrivate *priv =
-		SOUP_AUTH_DOMAIN_BASIC_GET_PRIVATE (domain);
+		soup_auth_domain_basic_get_instance_private (SOUP_AUTH_DOMAIN_BASIC (domain));
 
 	if (priv->auth_dnotify)
 		priv->auth_dnotify (priv->auth_data);
@@ -235,7 +232,7 @@ soup_auth_domain_basic_accepts (SoupAuthDomain *domain, SoupMessage *msg,
 				const char *header)
 {
 	SoupAuthDomainBasicPrivate *priv =
-		SOUP_AUTH_DOMAIN_BASIC_GET_PRIVATE (domain);
+		soup_auth_domain_basic_get_instance_private (SOUP_AUTH_DOMAIN_BASIC (domain));
 	char *username, *password;
 	gboolean ok = FALSE;
 
@@ -300,8 +297,6 @@ soup_auth_domain_basic_class_init (SoupAuthDomainBasicClass *basic_class)
 		SOUP_AUTH_DOMAIN_CLASS (basic_class);
 	GObjectClass *object_class = G_OBJECT_CLASS (basic_class);
 
-	g_type_class_add_private (basic_class, sizeof (SoupAuthDomainBasicPrivate));
-
 	auth_domain_class->accepts        = soup_auth_domain_basic_accepts;
 	auth_domain_class->challenge      = soup_auth_domain_basic_challenge;
 	auth_domain_class->check_password = soup_auth_domain_basic_check_password;
@@ -316,6 +311,11 @@ soup_auth_domain_basic_class_init (SoupAuthDomainBasicClass *basic_class)
 	 * Alias for the #SoupAuthDomainBasic:auth-callback property.
 	 * (The #SoupAuthDomainBasicAuthCallback.)
 	 **/
+	/**
+	 * SoupAuthDomainBasic:auth-callback: (type SoupAuthDomainBasicAuthCallback)
+	 *
+	 * The #SoupAuthDomainBasicAuthCallback
+	 */
 	g_object_class_install_property (
 		object_class, PROP_AUTH_CALLBACK,
 		g_param_spec_pointer (SOUP_AUTH_DOMAIN_BASIC_AUTH_CALLBACK,
@@ -328,6 +328,11 @@ soup_auth_domain_basic_class_init (SoupAuthDomainBasicClass *basic_class)
 	 * Alias for the #SoupAuthDomainBasic:auth-data property.
 	 * (The data to pass to the #SoupAuthDomainBasicAuthCallback.)
 	 **/
+	/**
+	 * SoupAuthDomainBasic:auth-data:
+	 *
+	 * The data to pass to the #SoupAuthDomainBasicAuthCallback
+	 */
 	g_object_class_install_property (
 		object_class, PROP_AUTH_DATA,
 		g_param_spec_pointer (SOUP_AUTH_DOMAIN_BASIC_AUTH_DATA,
